tfactl availability
Use the tfactl availability command to enable or disable resources for Availability Score, and to search a specific data type in the telemetry cache.
Syntax
tfactl availability enable|disable|dumpcache
tfactl availability enable -key key -value value | -list
tfactl availability disable -key key -value value [-for nd|D|h|H|m|M] | -list [-for nd|D|h|H|m|M]
tfactl availability dumpcache [-data_type data_type]
Parameters
tfactl availability enable Command Parameters
| Parameter | Description |
|---|---|
-type resource_type | Specify the resource type that you want to enable. |
-key key | Specify the key of the resource that you want to enable. |
-list | Displays the list of resources that are available for enabling. |
Parameters
Table 9-47 tfactl availability disable Command Parameters
| Parameter | Description |
|---|---|
-type resource_type | Specify the resource type that you want to enable. |
-key key | Specify the key of the resource that you want to enable. |
[-for nd|D|h|H|m|M] | -list [-for nd|D|h|H|m|M] | Specify the days, hours, or minutes to determine how long the resource will be disabled. Default is 7 days. |
-list | Displays the list of resources that are available for disabling.. |
Parameters
tfactl availability dumpcache Command Parameters
| Parameter | Description |
|---|---|
-data_type data_type | Specify the data type that you want to search in the telemetry cache. |
Example tfactl availability enable
tfactl availability enable -list
tfactl availability enable -type server_disk -key filesystem -value "/dev/xvdad1"
tfactl availability enable -type server_network -key interface -value eth1
tfactl availability disable
tfactl availability disable -list
tfactl availability disable -list -for 3d
tfactl availability disable -list -for 15h
tfactl availability disable -type server_disk -key filesystem -value "/dev/xvdad1"
tfactl availability disable -type server_network -key interface -value eth1
tfactl availability disable -type server_disk -key filesystem -value "/dev/xvdad1" -for 3d
tfactl availability disable -type server_network -key interface -value eth1 -for 12h
tfactl availability dumpcache
tfactl availability dumpcache
tfactl availability dumpcache -data_type pdb
tfactl availability dumpcache -data_type db_tablespace
tfactl availability dumpcache -data_type db_backup
tfactl availability dumpcache -data_type cstate